@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,13 +8,12 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_cloudformation
 import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.aws_route53
 import aws_cdk.core
+import constructs
 __all__ = []
 
 publication.publish()
